// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Debug Utilities for Qt.
#include "gui/base/debug_util.h"

#ifdef OS_WINDOWS
#include <windows.h>
#endif

#include "base/base.h"
#include "base/util.h"

namespace mozc {
namespace gui {
namespace {
void SendLogToDebugger(const char *msg) {
#if defined(DEBUG) && defined(OS_WINDOWS)
  wstring wmsg;
  Util::UTF8ToWide(msg, &wmsg);
  ::OutputDebugString(wmsg.c_str());
#endif  // OS_WINDOWS && DEBUG
}
}  // namespace

void DebugUtil::MessageHandler(QtMsgType type, const char *msg) {
  switch (type) {
    case QtDebugMsg:
      SendLogToDebugger(msg);
      LOG(INFO) << msg;
      break;
    case QtWarningMsg:
      SendLogToDebugger(msg);
      LOG(WARNING) << msg;
      break;
    case QtCriticalMsg:
      SendLogToDebugger(msg);
      LOG(ERROR) << msg;
      break;
    case QtFatalMsg:
      SendLogToDebugger(msg);
      LOG(FATAL) << msg;
      break;
  }
}
}  // namespace gui
}  // namespace mozc
